@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_MESSAGEFOLDERATTRIBUTE_H
-#define AKONADI_MESSAGEFOLDERATTRIBUTE_H
+#pragma once
 
 #include "akonadi-mime_export.h"
 
@@ -13,7 +12,8 @@
 
 #include <QByteArray>
 
-namespace Akonadi {
+namespace Akonadi
+{
 /**
   Message folder information. Used eg. by mail clients to decide how to display the content of such collections
   @since 4.4
@@ -34,7 +34,7 @@ public:
     /**
       Destructor.
     */
-    ~MessageFolderAttribute();
+    ~MessageFolderAttribute() override;
 
     /**
       Indicates if the folder is supposed to contain mostly outbound messages.
@@ -62,4 +62,3 @@ private:
 };
 }
 
-#endif
